@@ -194,6 +194,24 @@ class SlaiCliClient:
         res.raise_for_status()
         return res.json()
 
+    def list_model_artifacts(self, *, model_version_id):
+        body = {
+            "action": "list",
+            "model_version_id": model_version_id,
+        }
+
+        res = requests.post(
+            f"{self.BASE_URL}/cli/model-artifact",
+            auth=HTTPBasicAuth(self.client_id, self.client_secret),
+            headers={
+                "User-Agent": self.user_agent_header,
+            },
+            json=body,
+            timeout=REQUESTS_TIMEOUT,
+        )
+        res.raise_for_status()
+        return res.json()
+
     def retrieve_model_artifact(self, *, model_version_id, model_artifact_id):
         body = {
             "action": "retrieve",
@@ -216,14 +234,23 @@ class SlaiCliClient:
         return res.json()
 
     def create_model_artifact(
-        self, *, model_version_id, model_data, artifact_type, artifact_requirements
+        self,
+        *,
+        model_version_id,
+        model_data,
+        artifact_type,
+        artifact_notebook,
+        artifact_requirements,
+        custom_metadata,
     ):
         body = {
             "action": "create",
             "model_version_id": model_version_id,
             "model_data": model_data,
             "artifact_type": artifact_type,
+            "artifact_notebook": artifact_notebook,
             "artifact_requirements": artifact_requirements,
+            "custom_metadata": custom_metadata,
         }
 
         res = requests.post(
