@@ -5,12 +5,13 @@ from requests.auth import HTTPBasicAuth
 from importlib import import_module
 
 from slai.modules.parameters import from_config
+from slai.config import get_api_base_url
 from slai.modules.runtime import detect_runtime, detect_credentials
 
 REQUESTS_TIMEOUT = 15
 
 
-def get_identity_client(*, client_id=None, client_secret=None):
+def get_identity_client(*, client_id=None, client_secret=None, key_type=None):
     import_path = from_config(
         "IDENTITY_CLIENT",
         "slai.clients.identity.IdentityClient",
@@ -18,24 +19,17 @@ def get_identity_client(*, client_id=None, client_secret=None):
     class_ = import_path.split(".")[-1]
     path = ".".join(import_path.split(".")[:-1])
     return getattr(import_module(path), class_)(
-        client_id=client_id, client_secret=client_secret
+        client_id=client_id, client_secret=client_secret, key_type=key_type
     )
 
 
 class IdentityClient:
-    STAGE = from_config(
-        key="STAGE",
-        default="staging",
-    )
+    BASE_URL = get_api_base_url()
 
-    BASE_URL = from_config(
-        key="BASE_URL",
-        default=f"https://api.slai.io/{STAGE}",
-    )
-
-    def __init__(self, client_id=None, client_secret=None):
+    def __init__(self, client_id=None, client_secret=None, key_type=None):
         self.runtime = detect_runtime()
         self.credentials_loaded = False
+        self.key_type = key_type
 
         if not client_id or not client_secret:
             try:
@@ -80,3 +74,21 @@ class IdentityClient:
         )
         res.raise_for_status()
         return res.json()
+
+    def validate_credentials(self):
+        if not self.credentials_loaded:
+            raise NoCredentialsFound("no_credentials_loaded")
+
+        body = {}
+        if self.key_type is not None:
+            body["key_type"] = self.key_type
+
+        res = requests.post(
+            f"{self.BASE_URL}/cli/validate-credentials",
+            auth=HTTPBasicAuth(self.client_id, self.client_secret),
+            headers={},
+            json=body,
+            timeout=REQUESTS_TIMEOUT,
+        )
+        res.raise_for_status()
+        return res.json()
