@@ -28,7 +28,14 @@ class ModelClient:
         return self.project_client.get_project_name()
 
     def create_model_artifact(
-        self, *, model_data, artifact_type, artifact_requirements, model_version_id=None
+        self,
+        *,
+        model_data,
+        artifact_type,
+        artifact_notebook,
+        artifact_requirements,
+        model_version_id=None,
+        custom_metadata={},
     ):
         if model_version_id is None:
             model_version_id = self.model["model_version_id"]
@@ -37,7 +44,9 @@ class ModelClient:
             model_version_id=model_version_id,
             model_data=model_data,
             artifact_type=artifact_type,
+            artifact_notebook=artifact_notebook,
             artifact_requirements=artifact_requirements,
+            custom_metadata=custom_metadata,
         )
         return model_artifact
 
@@ -93,6 +102,12 @@ class ModelClient:
         )
         return model_artifact
 
+    def list_model_artifacts(self, model_version_id):
+        model_artifacts = self.cli_client.retrieve_model_artifact(
+            model_version_id=model_version_id,
+        )
+        return model_artifacts
+
 
 class MockModelClient:
     def __init__(self, *, model_name, project_name):
@@ -102,7 +117,13 @@ class MockModelClient:
         return "MOCK_PROJECT_NAME"
 
     def create_model_artifact(
-        self, *, model_data, artifact_type, artifact_requirements
+        self,
+        *,
+        model_data,
+        artifact_type,
+        artifact_notebook,
+        artifact_requirements,
+        custom_metadata,
     ):
         return {
             "id": "60329220dd191a68cfb474ec",
